package com.siginfo.vo;

public class TbIntPhaseVO {
	
	private String regionCd;
	private Long intNo;
	private Integer mapNo;
	private Integer intMainphase;
	private String aRing1PhaseConfCd;
	private String aRing2PhaseConfCd;
	private String aRing3PhaseConfCd;
	private String aRing4PhaseConfCd;
	private String aRing5PhaseConfCd;
	private String aRing6PhaseConfCd;
	private String aRing7PhaseConfCd;
	private String aRing8PhaseConfCd;
	private String bRing1PhaseConfCd;
	private String bRing2PhaseConfCd;
	private String bRing3PhaseConfCd;
	private String bRing4PhaseConfCd;
	private String bRing5PhaseConfCd;
	private String bRing6PhaseConfCd;
	private String bRing7PhaseConfCd;
	private String bRing8PhaseConfCd;
	private String aRing1StrtLinkCd;
	private String aRing2StrtLinkCd;
	private String aRing3StrtLinkCd;
	private String aRing4StrtLinkCd;
	private String aRing5StrtLinkCd;
	private String aRing6StrtLinkCd;
	private String aRing7StrtLinkCd;
	private String aRing8StrtLinkCd;
	private String bRing1StrtLinkCd;
	private String bRing2StrtLinkCd;
	private String bRing3StrtLinkCd;
	private String bRing4StrtLinkCd;
	private String bRing5StrtLinkCd;
	private String bRing6StrtLinkCd;
	private String bRing7StrtLinkCd;
	private String bRing8StrtLinkCd;
	private String aRing1EndLinkCd;
	private String aRing2EndLinkCd;
	private String aRing3EndLinkCd;
	private String aRing4EndLinkCd;
	private String aRing5EndLinkCd;
	private String aRing6EndLinkCd;
	private String aRing7EndLinkCd;
	private String aRing8EndLinkCd;
	private String bRing1EndLinkCd;
	private String bRing2EndLinkCd;
	private String bRing3EndLinkCd;
	private String bRing4EndLinkCd;
	private String bRing5EndLinkCd;
	private String bRing6EndLinkCd;
	private String bRing7EndLinkCd;
	private String bRing8EndLinkCd;
	private Integer a1FlowNum;
	private Integer a2FlowNum;
	private Integer a3FlowNum;
	private Integer a4FlowNum;
	private Integer a5FlowNum;
	private Integer a6FlowNum;
	private Integer a7FlowNum;
	private Integer a8FlowNum;
	private Integer b1FlowNum;
	private Integer b2FlowNum;
	private Integer b3FlowNum;
	private Integer b4FlowNum;
	private Integer b5FlowNum;
	private Integer b6FlowNum;
	private Integer b7FlowNum;
	private Integer b8FlowNum;
	public String getRegionCd() {
		return regionCd;
	}
	public void setRegionCd(String regionCd) {
		this.regionCd = regionCd;
	}
	public Long getIntNo() {
		return intNo;
	}
	public void setIntNo(Long intNo) {
		this.intNo = intNo;
	}
	public Integer getMapNo() {
		return mapNo;
	}
	public void setMap_no(Integer mapNo) {
		this.mapNo = mapNo;
	}
	public Integer getIntMainphase() {
		return intMainphase;
	}
	public void setIntMainPhase(Integer intMainphase) {
		this.intMainphase = intMainphase;
	}
	public String getaRing1PhaseConfCd() {
		return aRing1PhaseConfCd;
	}
	public void setaRing1PhaseConfCd(String aRing1PhaseConfCd) {
		this.aRing1PhaseConfCd = aRing1PhaseConfCd;
	}
	public String getaRing2PhaseConfCd() {
		return aRing2PhaseConfCd;
	}
	public void setaRing2PhaseConfCd(String aRing2PhaseConfCd) {
		this.aRing2PhaseConfCd = aRing2PhaseConfCd;
	}
	public String getaRing3PhaseConfCd() {
		return aRing3PhaseConfCd;
	}
	public void setaRing3PhaseConfCd(String aRing3PhaseConfCd) {
		this.aRing3PhaseConfCd = aRing3PhaseConfCd;
	}
	public String getaRing4PhaseConfCd() {
		return aRing4PhaseConfCd;
	}
	public void setaRing4PhaseConfCd(String aRing4PhaseConfCd) {
		this.aRing4PhaseConfCd = aRing4PhaseConfCd;
	}
	public String getaRing5PhaseConfCd() {
		return aRing5PhaseConfCd;
	}
	public void setaRing5PhaseConfCd(String aRing5PhaseConfCd) {
		this.aRing5PhaseConfCd = aRing5PhaseConfCd;
	}
	public String getaRing6PhaseConfCd() {
		return aRing6PhaseConfCd;
	}
	public void setaRing6PhaseConfCd(String aRing6PhaseConfCd) {
		this.aRing6PhaseConfCd = aRing6PhaseConfCd;
	}
	public String getaRing7PhaseConfCd() {
		return aRing7PhaseConfCd;
	}
	public void setaRing7PhaseConfCd(String aRing7PhaseConfCd) {
		this.aRing7PhaseConfCd = aRing7PhaseConfCd;
	}
	public String getaRing8PhaseConfCd() {
		return aRing8PhaseConfCd;
	}
	public void setaRing8PhaseConfCd(String aRing8PhaseConfCd) {
		this.aRing8PhaseConfCd = aRing8PhaseConfCd;
	}
	public String getbRing1PhaseConfCd() {
		return bRing1PhaseConfCd;
	}
	public void setbRing1PhaseConfCd(String bRing1PhaseConfCd) {
		this.bRing1PhaseConfCd = bRing1PhaseConfCd;
	}
	public String getbRing2PhaseConfCd() {
		return bRing2PhaseConfCd;
	}
	public void setbRing2PhaseConfCd(String bRing2PhaseConfCd) {
		this.bRing2PhaseConfCd = bRing2PhaseConfCd;
	}
	public String getbRing3PhaseConfCd() {
		return bRing3PhaseConfCd;
	}
	public void setbRing3PhaseConfCd(String bRing3PhaseConfCd) {
		this.bRing3PhaseConfCd = bRing3PhaseConfCd;
	}
	public String getbRing4PhaseConfCd() {
		return bRing4PhaseConfCd;
	}
	public void setbRing4PhaseConfCd(String bRing4PhaseConfCd) {
		this.bRing4PhaseConfCd = bRing4PhaseConfCd;
	}
	public String getbRing5PhaseConfCd() {
		return bRing5PhaseConfCd;
	}
	public void setbRing5PhaseConfCd(String bRing5PhaseConfCd) {
		this.bRing5PhaseConfCd = bRing5PhaseConfCd;
	}
	public String getbRing6PhaseConfCd() {
		return bRing6PhaseConfCd;
	}
	public void setbRing6PhaseConfCd(String bRing6PhaseConfCd) {
		this.bRing6PhaseConfCd = bRing6PhaseConfCd;
	}
	public String getbRing7PhaseConfCd() {
		return bRing7PhaseConfCd;
	}
	public void setbRing7PhaseConfCd(String bRing7PhaseConfCd) {
		this.bRing7PhaseConfCd = bRing7PhaseConfCd;
	}
	public String getbRing8PhaseConfCd() {
		return bRing8PhaseConfCd;
	}
	public void setbRing8PhaseConfCd(String bRing8PhaseConfCd) {
		this.bRing8PhaseConfCd = bRing8PhaseConfCd;
	}
	public String getaRing1StrtLinkCd() {
		return aRing1StrtLinkCd;
	}
	public void setaRing1StrtLinkCd(String aRing1StrtLinkCd) {
		this.aRing1StrtLinkCd = aRing1StrtLinkCd;
	}
	public String getaRing2StrtLinkCd() {
		return aRing2StrtLinkCd;
	}
	public void setaRing2StrtLinkCd(String aRing2StrtLinkCd) {
		this.aRing2StrtLinkCd = aRing2StrtLinkCd;
	}
	public String getaRing3StrtLinkCd() {
		return aRing3StrtLinkCd;
	}
	public void setaRing3StrtLinkCd(String aRing3StrtLinkCd) {
		this.aRing3StrtLinkCd = aRing3StrtLinkCd;
	}
	public String getaRing4StrtLinkCd() {
		return aRing4StrtLinkCd;
	}
	public void setaRing4StrtLinkCd(String aRing4StrtLinkCd) {
		this.aRing4StrtLinkCd = aRing4StrtLinkCd;
	}
	public String getaRing5StrtLinkCd() {
		return aRing5StrtLinkCd;
	}
	public void setaRing5StrtLinkCd(String aRing5StrtLinkCd) {
		this.aRing5StrtLinkCd = aRing5StrtLinkCd;
	}
	public String getaRing6StrtLinkCd() {
		return aRing6StrtLinkCd;
	}
	public void setaRing6StrtLinkCd(String aRing6StrtLinkCd) {
		this.aRing6StrtLinkCd = aRing6StrtLinkCd;
	}
	public String getaRing7StrtLinkCd() {
		return aRing7StrtLinkCd;
	}
	public void setaRing7StrtLinkCd(String aRing7StrtLinkCd) {
		this.aRing7StrtLinkCd = aRing7StrtLinkCd;
	}
	public String getaRing8StrtLinkCd() {
		return aRing8StrtLinkCd;
	}
	public void setaRing8StrtLinkCd(String aRing8StrtLinkCd) {
		this.aRing8StrtLinkCd = aRing8StrtLinkCd;
	}
	public String getbRing1StrtLinkCd() {
		return bRing1StrtLinkCd;
	}
	public void setbRing1StrtLinkCd(String bRing1StrtLinkCd) {
		this.bRing1StrtLinkCd = bRing1StrtLinkCd;
	}
	public String getbRing2StrtLinkCd() {
		return bRing2StrtLinkCd;
	}
	public void setbRing2StrtLinkCd(String bRing2StrtLinkCd) {
		this.bRing2StrtLinkCd = bRing2StrtLinkCd;
	}
	public String getbRing3StrtLinkCd() {
		return bRing3StrtLinkCd;
	}
	public void setbRing3StrtLinkCd(String bRing3StrtLinkCd) {
		this.bRing3StrtLinkCd = bRing3StrtLinkCd;
	}
	public String getbRing4StrtLinkCd() {
		return bRing4StrtLinkCd;
	}
	public void setbRing4StrtLinkCd(String bRing4StrtLinkCd) {
		this.bRing4StrtLinkCd = bRing4StrtLinkCd;
	}
	public String getbRing5StrtLinkCd() {
		return bRing5StrtLinkCd;
	}
	public void setbRing5StrtLinkCd(String bRing5StrtLinkCd) {
		this.bRing5StrtLinkCd = bRing5StrtLinkCd;
	}
	public String getbRing6StrtLinkCd() {
		return bRing6StrtLinkCd;
	}
	public void setbRing6StrtLinkCd(String bRing6StrtLinkCd) {
		this.bRing6StrtLinkCd = bRing6StrtLinkCd;
	}
	public String getbRing7StrtLinkCd() {
		return bRing7StrtLinkCd;
	}
	public void setbRing7StrtLinkCd(String bRing7StrtLinkCd) {
		this.bRing7StrtLinkCd = bRing7StrtLinkCd;
	}
	public String getbRing8StrtLinkCd() {
		return bRing8StrtLinkCd;
	}
	public void setbRing8StrtLinkCd(String bRing8StrtLinkCd) {
		this.bRing8StrtLinkCd = bRing8StrtLinkCd;
	}
	public String getaRing1EndLinkCd() {
		return aRing1EndLinkCd;
	}
	public void setaRing1EndLinkCd(String aRing1EndLinkCd) {
		this.aRing1EndLinkCd = aRing1EndLinkCd;
	}
	public String getaRing2EndLinkCd() {
		return aRing2EndLinkCd;
	}
	public void setaRing2EndLinkCd(String aRing2EndLinkCd) {
		this.aRing2EndLinkCd = aRing2EndLinkCd;
	}
	public String getaRing3EndLinkCd() {
		return aRing3EndLinkCd;
	}
	public void setaRing3EndLinkCd(String aRing3EndLinkCd) {
		this.aRing3EndLinkCd = aRing3EndLinkCd;
	}
	public String getaRing4EndLinkCd() {
		return aRing4EndLinkCd;
	}
	public void setaRing4EndLinkCd(String aRing4EndLinkCd) {
		this.aRing4EndLinkCd = aRing4EndLinkCd;
	}
	public String getaRing5EndLinkCd() {
		return aRing5EndLinkCd;
	}
	public void setaRing5EndLinkCd(String aRing5EndLinkCd) {
		this.aRing5EndLinkCd = aRing5EndLinkCd;
	}
	public String getaRing6EndLinkCd() {
		return aRing6EndLinkCd;
	}
	public void setaRing6EndLinkCd(String aRing6EndLinkCd) {
		this.aRing6EndLinkCd = aRing6EndLinkCd;
	}
	public String getaRing7EndLinkCd() {
		return aRing7EndLinkCd;
	}
	public void setaRing7EndLinkCd(String aRing7EndLinkCd) {
		this.aRing7EndLinkCd = aRing7EndLinkCd;
	}
	public String getaRing8EndLinkCd() {
		return aRing8EndLinkCd;
	}
	public void setaRing8EndLinkCd(String aRing8EndLinkCd) {
		this.aRing8EndLinkCd = aRing8EndLinkCd;
	}
	public String getbRing1EndLinkCd() {
		return bRing1EndLinkCd;
	}
	public void setbRing1EndLinkCd(String bRing1EndLinkCd) {
		this.bRing1EndLinkCd = bRing1EndLinkCd;
	}
	public String getbRing2EndLinkCd() {
		return bRing2EndLinkCd;
	}
	public void setbRing2EndLinkCd(String bRing2EndLinkCd) {
		this.bRing2EndLinkCd = bRing2EndLinkCd;
	}
	public String getbRing3EndLinkCd() {
		return bRing3EndLinkCd;
	}
	public void setbRing3EndLinkCd(String bRing3EndLinkCd) {
		this.bRing3EndLinkCd = bRing3EndLinkCd;
	}
	public String getbRing4EndLinkCd() {
		return bRing4EndLinkCd;
	}
	public void setbRing4EndLinkCd(String bRing4EndLinkCd) {
		this.bRing4EndLinkCd = bRing4EndLinkCd;
	}
	public String getbRing5EndLinkCd() {
		return bRing5EndLinkCd;
	}
	public void setbRing5EndLinkCd(String bRing5EndLinkCd) {
		this.bRing5EndLinkCd = bRing5EndLinkCd;
	}
	public String getbRing6EndLinkCd() {
		return bRing6EndLinkCd;
	}
	public void setbRing6EndLinkCd(String bRing6EndLinkCd) {
		this.bRing6EndLinkCd = bRing6EndLinkCd;
	}
	public String getbRing7EndLinkCd() {
		return bRing7EndLinkCd;
	}
	public void setbRing7EndLinkCd(String bRing7EndLinkCd) {
		this.bRing7EndLinkCd = bRing7EndLinkCd;
	}
	public String getbRing8EndLinkCd() {
		return bRing8EndLinkCd;
	}
	public void setbRing8EndLinkCd(String bRing8EndLinkCd) {
		this.bRing8EndLinkCd = bRing8EndLinkCd;
	}
	public Integer getA1FlowNum() {
		return a1FlowNum;
	}
	public void setA1FlowNum(Integer a1FlowNum) {
		this.a1FlowNum = a1FlowNum;
	}
	public Integer getA2FlowNum() {
		return a2FlowNum;
	}
	public void setA2FlowNum(Integer a2FlowNum) {
		this.a2FlowNum = a2FlowNum;
	}
	public Integer getA3FlowNum() {
		return a3FlowNum;
	}
	public void setA3FlowNum(Integer a3FlowNum) {
		this.a3FlowNum = a3FlowNum;
	}
	public Integer getA4FlowNum() {
		return a4FlowNum;
	}
	public void setA4FlowNum(Integer a4FlowNum) {
		this.a4FlowNum = a4FlowNum;
	}
	public Integer getA5FlowNum() {
		return a5FlowNum;
	}
	public void setA5FlowNum(Integer a5FlowNum) {
		this.a5FlowNum = a5FlowNum;
	}
	public Integer getA6FlowNum() {
		return a6FlowNum;
	}
	public void setA6FlowNum(Integer a6FlowNum) {
		this.a6FlowNum = a6FlowNum;
	}
	public Integer getA7FlowNum() {
		return a7FlowNum;
	}
	public void setA7FlowNum(Integer a7FlowNum) {
		this.a7FlowNum = a7FlowNum;
	}
	public Integer getA8FlowNum() {
		return a8FlowNum;
	}
	public void setA8FlowNum(Integer a8FlowNum) {
		this.a8FlowNum = a8FlowNum;
	}
	public Integer getB1FlowNum() {
		return b1FlowNum;
	}
	public void setB1FlowNum(Integer b1FlowNum) {
		this.b1FlowNum = b1FlowNum;
	}
	public Integer getB2FlowNum() {
		return b2FlowNum;
	}
	public void setB2FlowNum(Integer b2FlowNum) {
		this.b2FlowNum = b2FlowNum;
	}
	public Integer getB3FlowNum() {
		return b3FlowNum;
	}
	public void setB3FlowNum(Integer b3FlowNum) {
		this.b3FlowNum = b3FlowNum;
	}
	public Integer getB4FlowNum() {
		return b4FlowNum;
	}
	public void setB4FlowNum(Integer b4FlowNum) {
		this.b4FlowNum = b4FlowNum;
	}
	public Integer getB5FlowNum() {
		return b5FlowNum;
	}
	public void setB5FlowNum(Integer b5FlowNum) {
		this.b5FlowNum = b5FlowNum;
	}
	public Integer getB6FlowNum() {
		return b6FlowNum;
	}
	public void setB6FlowNum(Integer b6FlowNum) {
		this.b6FlowNum = b6FlowNum;
	}
	public Integer getB7FlowNum() {
		return b7FlowNum;
	}
	public void setB7FlowNum(Integer b7FlowNum) {
		this.b7FlowNum = b7FlowNum;
	}
	public Integer getB8FlowNum() {
		return b8FlowNum;
	}
	public void setB8FlowNum(Integer b8FlowNum) {
		this.b8FlowNum = b8FlowNum;
	}
	@Override
	public String toString() {
		return "TbIntPhaseVO [regionCd=" + regionCd + ", intNo=" + intNo + ", mapNo=" + mapNo + ", intMainPhase="
				+ intMainphase + ", aRing1PhaseConfCd=" + aRing1PhaseConfCd + ", aRing2PhaseConfCd=" + aRing2PhaseConfCd
				+ ", aRing3PhaseConfCd=" + aRing3PhaseConfCd + ", aRing4PhaseConfCd=" + aRing4PhaseConfCd
				+ ", aRing5PhaseConfCd=" + aRing5PhaseConfCd + ", aRing6PhaseConfCd=" + aRing6PhaseConfCd
				+ ", aRing7PhaseConfCd=" + aRing7PhaseConfCd + ", aRing8PhaseConfCd=" + aRing8PhaseConfCd
				+ ", bRing1PhaseConfCd=" + bRing1PhaseConfCd + ", bRing2PhaseConfCd=" + bRing2PhaseConfCd
				+ ", bRing3PhaseConfCd=" + bRing3PhaseConfCd + ", bRing4PhaseConfCd=" + bRing4PhaseConfCd
				+ ", bRing5PhaseConfCd=" + bRing5PhaseConfCd + ", bRing6PhaseConfCd=" + bRing6PhaseConfCd
				+ ", bRing7PhaseConfCd=" + bRing7PhaseConfCd + ", bRing8PhaseConfCd=" + bRing8PhaseConfCd
				+ ", aRing1StrtLinkCd=" + aRing1StrtLinkCd + ", aRing2StrtLinkCd=" + aRing2StrtLinkCd
				+ ", aRing3StrtLinkCd=" + aRing3StrtLinkCd + ", aRing4StrtLinkCd=" + aRing4StrtLinkCd
				+ ", aRing5StrtLinkCd=" + aRing5StrtLinkCd + ", aRing6StrtLinkCd=" + aRing6StrtLinkCd
				+ ", aRing7StrtLinkCd=" + aRing7StrtLinkCd + ", aRing8StrtLinkCd=" + aRing8StrtLinkCd
				+ ", bRing1StrtLinkCd=" + bRing1StrtLinkCd + ", bRing2StrtLinkCd=" + bRing2StrtLinkCd
				+ ", bRing3StrtLinkCd=" + bRing3StrtLinkCd + ", bRing4StrtLinkCd=" + bRing4StrtLinkCd
				+ ", bRing5StrtLinkCd=" + bRing5StrtLinkCd + ", bRing6StrtLinkCd=" + bRing6StrtLinkCd
				+ ", bRing7StrtLinkCd=" + bRing7StrtLinkCd + ", bRing8StrtLinkCd=" + bRing8StrtLinkCd
				+ ", aRing1EndLinkCd=" + aRing1EndLinkCd + ", aRing2EndLinkCd=" + aRing2EndLinkCd + ", aRing3EndLinkCd="
				+ aRing3EndLinkCd + ", aRing4EndLinkCd=" + aRing4EndLinkCd + ", aRing5EndLinkCd=" + aRing5EndLinkCd
				+ ", aRing6EndLinkCd=" + aRing6EndLinkCd + ", aRing7EndLinkCd=" + aRing7EndLinkCd + ", aRing8EndLinkCd="
				+ aRing8EndLinkCd + ", bRing1EndLinkCd=" + bRing1EndLinkCd + ", bRing2EndLinkCd=" + bRing2EndLinkCd
				+ ", bRing3EndLinkCd=" + bRing3EndLinkCd + ", bRing4EndLinkCd=" + bRing4EndLinkCd + ", bRing5EndLinkCd="
				+ bRing5EndLinkCd + ", bRing6EndLinkCd=" + bRing6EndLinkCd + ", bRing7EndLinkCd=" + bRing7EndLinkCd
				+ ", bRing8EndLinkCd=" + bRing8EndLinkCd + ", a1FlowNum=" + a1FlowNum + ", a2FlowNum=" + a2FlowNum
				+ ", a3FlowNum=" + a3FlowNum + ", a4FlowNum=" + a4FlowNum + ", a5FlowNum=" + a5FlowNum + ", a6FlowNum="
				+ a6FlowNum + ", a7FlowNum=" + a7FlowNum + ", a8FlowNum=" + a8FlowNum + ", b1FlowNum=" + b1FlowNum
				+ ", b2FlowNum=" + b2FlowNum + ", b3FlowNum=" + b3FlowNum + ", b4FlowNum=" + b4FlowNum + ", b5FlowNum="
				+ b5FlowNum + ", b6FlowNum=" + b6FlowNum + ", b7FlowNum=" + b7FlowNum + ", b8FlowNum=" + b8FlowNum
				+ "]";
	}
	
	

}
